@@ -23,15 +23,16 @@ class ServiceDescriptor(object):
                 {'attributes': attributes, 'serviceEndpoint': service_endpoint})
 
     @staticmethod
-    def authorization_service_descriptor(service_endpoint):
+    def authorization_service_descriptor(attributes, service_endpoint):
         """
         Authorization service descriptor.
 
+        :param attributes: attributes of the authorization service, dict
         :param service_endpoint: identifier of the service inside the asset DDO, str
         :return: Service descriptor.
         """
         return (ServiceTypes.AUTHORIZATION,
-                {'attributes': {'main': {}}, 'serviceEndpoint': service_endpoint})
+                {'attributes': attributes, 'serviceEndpoint': service_endpoint})
 
     @staticmethod
     def access_service_descriptor(attributes, service_endpoint):
