@@ -1,5 +1,3 @@
-#  Copyright 2018 Ocean Protocol Foundation
-#  SPDX-License-Identifier: Apache-2.0
 import os
 
 import pytest
@@ -9,20 +7,16 @@ from contracts_lib_py.web3_provider import Web3Provider
 from web3 import HTTPProvider, Web3
 
 from common_utils_py.agreements.service_agreement import ServiceAgreement, ServiceTypes
-from common_utils_py.aquarius import AquariusProvider
 from common_utils_py.ddo.ddo import DDO
 from common_utils_py.did import DID
-from tests.resources.helper_functions import (
-    get_consumer_account,
-    get_ddo_sample,
-    get_metadata,
-    get_publisher_account
-)
+from common_utils_py.metadata import MetadataProvider
+from tests.resources.helper_functions import (get_consumer_account, get_ddo_sample, get_ddo_sample2,
+                                              get_metadata, get_publisher_account)
 
 
-def get_aquarius_url():
-    if os.getenv('AQUARIUS_URL'):
-        return os.getenv('AQUARIUS_URL')
+def get_metadata_url():
+    if os.getenv('METADATA_URL'):
+        return os.getenv('METADATA_URL')
     return 'http://localhost:5000'
 
 
@@ -35,7 +29,8 @@ def get_keeper_url():
 @pytest.fixture(autouse=True)
 def setup_all():
     Web3Provider.get_web3('http://localhost:8545')
-    ContractHandler.artifacts_path = os.path.expanduser('~/.nevermind/nevermind-contracts/artifacts')
+    ContractHandler.artifacts_path = os.path.expanduser(
+        '~/.nevermined/nevermined-contracts/artifacts')
     Keeper.get_instance()
 
 
@@ -50,8 +45,8 @@ def consumer_account():
 
 
 @pytest.fixture
-def aquarius():
-    return AquariusProvider.get_aquarius(get_aquarius_url())
+def metadata_instance():
+    return MetadataProvider.get_metadata_provider(get_metadata_url())
 
 
 @pytest.fixture
@@ -69,6 +64,16 @@ def metadata():
     return get_metadata()
 
 
+@pytest.fixture
+def ddo_sample():
+    return get_ddo_sample()
+
+
+@pytest.fixture
+def ddo_sample_2():
+    return get_ddo_sample2()
+
+
 @pytest.fixture
 def setup_agreements_environment():
     consumer_acc = get_consumer_account()
@@ -80,7 +85,7 @@ def setup_agreements_environment():
     keeper.did_registry.register(
         ddo.asset_id,
         checksum=Web3Provider.get_web3().toBytes(hexstr=ddo.asset_id),
-        url='aquarius:5000',
+        url='metadata:5000',
         account=publisher_acc,
         providers=None
     )
@@ -93,7 +98,7 @@ def setup_agreements_environment():
     (access_cond_id,
      lock_cond_id,
      escrow_cond_id) = service_agreement.generate_agreement_condition_ids(
-            agreement_id, asset_id, consumer_acc.address, publisher_acc.address, keeper
+        agreement_id, asset_id, consumer_acc.address, publisher_acc.address, keeper
     )
 
     return (
